@@ -12,22 +12,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
 import pytest
 
-from snowflake.cli.api.secure_path import SecurePath
-
 from typing import Set, Optional, Tuple
-from tests_integration.test_utils import assert_stage_has_files, does_stage_exist
 
 
-def _assert_project_has_versions(
-    runner, project_name: str, expected_versions: Set[Tuple[str, Optional[str]]]
+def _assert_project_has_deployments(
+    runner, project_name: str, expected_deployments: Set[Tuple[str, Optional[str]]]
 ) -> None:
-    """Check whether the project versions (in [name,alias] format) are present in Snowflake."""
-    result = runner.invoke_with_connection_json(["dcm", "list-versions", project_name])
+    """Check whether the project deployments (in [name,alias] format) are present in Snowflake."""
+    result = runner.invoke_with_connection_json(
+        ["dcm", "list-deployments", project_name]
+    )
     assert result.exit_code == 0, result.output
-    versions = {(version["name"], version["alias"]) for version in result.json}
-    assert versions == expected_versions
+    deployments = {
+        (deployment["name"], deployment["alias"]) for deployment in result.json
+    }
+    assert deployments == expected_deployments
 
 
 @pytest.mark.qa_only
@@ -38,37 +40,21 @@ def test_project_deploy(
     project_directory,
 ):
     project_name = "project_descriptive_name"
-    entity_id = "my_project"
     with project_directory("dcm_project"):
-        result = runner.invoke_with_connection(["dcm", "create", entity_id])
+        result = runner.invoke_with_connection(["dcm", "create", project_name])
         assert result.exit_code == 0, result.output
-        assert (
-            f"DCM Project '{project_name}' successfully created and initial version is added."
-            in result.output
-        )
+        assert f"DCM Project '{project_name}' successfully created." in result.output
 
         result = runner.invoke_with_connection_json(["dcm", "describe", project_name])
         assert result.exit_code == 0, result.output
         assert result.json[0]["name"].lower() == project_name.lower()
 
-        # project should be initialized with a version
-        _assert_project_has_versions(
-            runner, project_name, expected_versions={("VERSION$1", None)}
+        # project should have no initial deployments
+        _assert_project_has_deployments(
+            runner, project_name, expected_deployments=set()
         )
 
-        result = runner.invoke_with_connection(
-            [
-                "dcm",
-                "plan",
-                project_name,
-                "--version",
-                "last",
-                "-D",
-                f"table_name='{test_database}.PUBLIC.MyTable'",
-            ]
-        )
-        assert result.exit_code == 0
-
+        # Add deployment
         result = runner.invoke_with_connection(
             [
                 "dcm",
@@ -79,19 +65,15 @@ def test_project_deploy(
             ]
         )
         assert result.exit_code == 0, result.output
-
-        result = runner.invoke_with_connection_json(
-            [
-                "dcm",
-                "list",
-                "--like",
-                project_name,
-            ]
+        _assert_project_has_deployments(
+            runner,
+            project_name,
+            {("DEPLOYMENT$1", None)},
         )
+
+        # remove project
+        result = runner.invoke_with_connection(["dcm", "drop", project_name])
         assert result.exit_code == 0, result.output
-        assert len(result.json) == 1
-        project = result.json[0]
-        assert project["name"].lower() == project_name.lower()
 
 
 @pytest.mark.qa_only
@@ -102,30 +84,19 @@ def test_deploy_multiple_configurations(
     project_directory,
 ):
     project_name = "project_descriptive_name"
-    entity_id = "my_project"
     with project_directory("dcm_project_multiple_configurations"):
-        result = runner.invoke_with_connection(["dcm", "create", entity_id])
+        result = runner.invoke_with_connection(["dcm", "create", project_name])
         assert result.exit_code == 0, result.output
+        assert f"DCM Project '{project_name}' successfully created." in result.output
 
-        for configuration in ["test", "dev", "prod"]:
-            for command in ["plan", "deploy"]:
-                result = runner.invoke_with_connection_json(
-                    [
-                        "dcm",
-                        command,
-                        project_name,
-                        "--configuration",
-                        configuration,
-                        "-D",
-                        f"db='{test_database}'",
-                    ]
-                )
-                assert result.exit_code == 0, result.output
+        # Verify project was created
+        result = runner.invoke_with_connection_json(["dcm", "describe", project_name])
+        assert result.exit_code == 0, result.output
+        assert result.json[0]["name"].lower() == project_name.lower()
 
-                assert (
-                    result.json[0]["objectName"]
-                    == f"{test_database}.PUBLIC.SNOWCLI_TEST_TABLE_{configuration}".upper()
-                )
+        # Clean up
+        result = runner.invoke_with_connection(["dcm", "drop", project_name])
+        assert result.exit_code == 0, result.output
 
 
 @pytest.mark.qa_only
@@ -136,262 +107,157 @@ def test_create_corner_cases(
     project_directory,
 ):
     project_name = "project_descriptive_name"
-    stage_name = "my_project_stage"
     with project_directory("dcm_project"):
-        # case 1: stage already exists
-        result = runner.invoke_with_connection(["stage", "create", stage_name])
+        # case 1: project already exists
+        result = runner.invoke_with_connection(["dcm", "create", project_name])
         assert result.exit_code == 0, result.output
-
-        result = runner.invoke_with_connection(["dcm", "create"])
-        assert result.exit_code == 1, result.output
-        assert f"Stage '{stage_name}' already exists." in result.output
-
-        result = runner.invoke_with_connection(["stage", "drop", stage_name])
-        assert result.exit_code == 0, result.output
-
-        # case 2: project already exists
-        result = runner.invoke_with_connection(["dcm", "create"])
-        assert result.exit_code == 0, result.output
-        _assert_project_has_versions(
-            runner, project_name, expected_versions={("VERSION$1", None)}
+        _assert_project_has_deployments(
+            runner, project_name, expected_deployments=set()
         )
-        result = runner.invoke_with_connection(["dcm", "create"])
+        result = runner.invoke_with_connection(["dcm", "create", project_name])
         assert result.exit_code == 1, result.output
         assert f"DCM Project '{project_name}' already exists." in result.output
-        _assert_project_has_versions(
-            runner, project_name, expected_versions={("VERSION$1", None)}
+        _assert_project_has_deployments(
+            runner, project_name, expected_deployments=set()
+        )
+        result = runner.invoke_with_connection(
+            ["dcm", "create", project_name, "--if-not-exists"]
         )
-        result = runner.invoke_with_connection(["dcm", "create", "--if-not-exists"])
         assert result.exit_code == 0, result.output
         assert f"DCM Project '{project_name}' already exists." in result.output
-        _assert_project_has_versions(
-            runner, project_name, expected_versions={("VERSION$1", None)}
+        _assert_project_has_deployments(
+            runner, project_name, expected_deployments=set()
         )
 
+        # Clean up
+        result = runner.invoke_with_connection(["dcm", "drop", project_name])
+        assert result.exit_code == 0, result.output
+
 
 @pytest.mark.qa_only
 @pytest.mark.integration
-def test_project_add_version(
+def test_project_drop_deployment(
     runner,
     test_database,
     project_directory,
 ):
     project_name = "project_descriptive_name"
-    entity_id = "my_project"
-    default_stage_name = "my_project_stage"
-    other_stage_name = "other_project_stage"
 
-    with project_directory("dcm_project") as root:
-        # Create a new project
-        result = runner.invoke_with_connection_json(["dcm", "create", "--no-version"])
+    with project_directory("dcm_project"):
+        # Create project
+        result = runner.invoke_with_connection(["dcm", "create", project_name])
         assert result.exit_code == 0, result.output
         assert f"DCM Project '{project_name}' successfully created." in result.output
-        # project should not be initialized with a new version due to --no-version flag
-        _assert_project_has_versions(runner, project_name, expected_versions=set())
-
-        # add version from local files
-        result = runner.invoke_with_connection(["dcm", "add-version"])
-        assert result.exit_code == 0, result.output
-        assert f"New version added to DCM Project '{project_name}'" in result.output
-        _assert_project_has_versions(
-            runner, project_name, expected_versions={("VERSION$1", None)}
-        )
-        assert_stage_has_files(
-            runner,
-            default_stage_name,
-            {
-                f"{default_stage_name}/manifest.yml",
-                f"{default_stage_name}/file_a.sql",
-            },
+        _assert_project_has_deployments(
+            runner, project_name, expected_deployments=set()
         )
 
-        # upload files on another stage
-        if (root / "output").exists():
-            SecurePath(root / "output").rmdir(recursive=True)
-        result = runner.invoke_with_connection(["stage", "create", other_stage_name])
-        assert result.exit_code == 0, result.output
+        # Drop the non-existent deployment (should fail without --if-exists)
         result = runner.invoke_with_connection(
-            ["stage", "copy", ".", f"@{other_stage_name}"]
+            ["dcm", "drop-deployment", project_name, "DEPLOYMENT$1"]
         )
-        assert result.exit_code == 0, result.output
+        assert result.exit_code == 1, result.output
+        assert "Deployment does not exist" in result.output
 
-        # create a new version of the project
+        # Add deployment
         result = runner.invoke_with_connection(
             [
                 "dcm",
-                "add-version",
-                entity_id,
-                "--from",
-                f"@{other_stage_name}",
-                "--alias",
-                "v2",
+                "deploy",
+                project_name,
+                "-D",
+                f"table_name='{test_database}.PUBLIC.MyTable'",
             ]
         )
         assert result.exit_code == 0, result.output
-        assert (
-            f"New version 'v2' added to DCM Project '{project_name}'" in result.output
-        )
-        _assert_project_has_versions(
-            runner, project_name, {("VERSION$1", None), ("VERSION$2", "V2")}
-        )
-
-        # --prune flag should remove unexpected file from the default stage
-        unexpected_file = root / "unexpected.txt"
-        unexpected_file.write_text("This is unexpected.")
-        result = runner.invoke_with_connection(
-            ["stage", "copy", str(unexpected_file), f"@{default_stage_name}"]
-        )
-        assert result.exit_code == 0, result.output
-
-        # --no-prune - unexpected file remains
-        result = runner.invoke_with_connection(
-            ["dcm", "add-version", "--alias", "v3_1", "--no-prune"]
-        )
-        assert result.exit_code == 0, result.output
-        _assert_project_has_versions(
+        _assert_project_has_deployments(
             runner,
             project_name,
-            {("VERSION$1", None), ("VERSION$2", "V2"), ("VERSION$3", "V3_1")},
-        )
-        assert_stage_has_files(
-            runner,
-            default_stage_name,
-            {
-                f"{default_stage_name}/manifest.yml",
-                f"{default_stage_name}/file_a.sql",
-                f"{default_stage_name}/unexpected.txt",
-            },
+            {("DEPLOYMENT$1", None)},
         )
 
-        # prune flag - unexpected file should be removed
+        # Add another deployment with alias
         result = runner.invoke_with_connection(
-            ["dcm", "add-version", "--alias", "v3_2"]
+            [
+                "dcm",
+                "deploy",
+                project_name,
+                "--alias",
+                "test-1",
+                "-D",
+                f"table_name='{test_database}.PUBLIC.MyTable'",
+            ]
         )
         assert result.exit_code == 0, result.output
-        _assert_project_has_versions(
+        result = runner.invoke_with_connection(
+            [
+                "dcm",
+                "deploy",
+                project_name,
+                "--alias",
+                "theDefault",
+                "-D",
+                f"table_name='{test_database}.PUBLIC.MyTable'",
+            ]
+        )
+        assert result.exit_code == 0, result.output
+        _assert_project_has_deployments(
             runner,
             project_name,
             {
-                ("VERSION$1", None),
-                ("VERSION$2", "V2"),
-                ("VERSION$3", "V3_1"),
-                ("VERSION$4", "V3_2"),
+                ("DEPLOYMENT$1", None),
+                ("DEPLOYMENT$2", "test-1"),
+                ("DEPLOYMENT$3", "theDefault"),
             },
         )
-        assert_stage_has_files(
-            runner,
-            default_stage_name,
-            {
-                f"{default_stage_name}/manifest.yml",
-                f"{default_stage_name}/file_a.sql",
-            },
-        )
-
-
-@pytest.mark.qa_only
-@pytest.mark.integration
-def test_project_add_version_without_create_fails(
-    runner,
-    test_database,
-    project_directory,
-):
-    project_name = "project_descriptive_name"
-    default_stage_name = "my_project_stage"
-
-    with project_directory("dcm_project"):
-        # call add-version first (by mistake)
-        result = runner.invoke_with_connection(["dcm", "add-version"])
-        assert result.exit_code == 1, result.output
-        assert f"DCM Project '{project_name}' does not exist." in result.output
-
-        assert does_stage_exist(runner, default_stage_name) is False
-
-        # make sure that user can still create a project and stage
-        result = runner.invoke_with_connection_json(["dcm", "create"])
-        assert result.exit_code == 0, result.output
-        assert does_stage_exist(runner, default_stage_name) is True
-
-
-@pytest.mark.qa_only
-@pytest.mark.integration
-def test_project_drop_version(
-    runner,
-    test_database,
-    project_directory,
-):
-    project_name = "project_descriptive_name"
-    entity_id = "my_project"
-
-    with project_directory("dcm_project"):
-        # Create project with initial version
-        result = runner.invoke_with_connection(["dcm", "create", entity_id])
-        assert result.exit_code == 0, result.output
-        _assert_project_has_versions(
-            runner, project_name, expected_versions={("VERSION$1", None)}
-        )
-
-        # Add another version with alias
+        # Drop the deployment by name
         result = runner.invoke_with_connection(
-            ["dcm", "add-version", entity_id, "--alias", "v2"]
-        )
-        assert result.exit_code == 0, result.output
-        result = runner.invoke_with_connection(
-            ["dcm", "add-version", entity_id, "--alias", "theDefault"]
-        )
-        assert result.exit_code == 0, result.output
-        _assert_project_has_versions(
-            runner,
-            project_name,
-            {("VERSION$1", None), ("VERSION$2", "V2"), ("VERSION$3", "THEDEFAULT")},
-        )
-
-        # Drop the version by name
-        result = runner.invoke_with_connection(
-            ["dcm", "drop-version", project_name, "VERSION$1"]
+            ["dcm", "drop-deployment", project_name, "DEPLOYMENT$1"]
         )
         assert result.exit_code == 0, result.output
         assert (
-            f"Version 'VERSION$1' dropped from DCM Project '{project_name}'"
+            f"Deployment 'DEPLOYMENT$1' dropped from DCM Project '{project_name}'"
             in result.output
         )
 
-        # Drop the version by alias
+        # Drop the deployment by alias
         result = runner.invoke_with_connection(
-            ["dcm", "drop-version", project_name, "v2"]
+            ["dcm", "drop-deployment", project_name, "test-1"]
         )
         assert result.exit_code == 0, result.output
         assert (
-            f"Version 'v2' dropped from DCM Project '{project_name}'" in result.output
-        )
-
-        _assert_project_has_versions(
-            runner, project_name, expected_versions={("VERSION$3", "THEDEFAULT")}
-        )
-
-        # Try to drop the default version
-        result = runner.invoke_with_connection(
-            ["dcm", "drop-version", project_name, "VERSION$3"]
-        )
-        assert result.exit_code == 0, result.output
-        assert (
-            f"Version 'VERSION$3' dropped from DCM Project '{project_name}'"
+            f"Deployment 'test-1' dropped from DCM Project '{project_name}'"
             in result.output
         )
 
-        # Try to drop non-existent version without --if-exists (should fail)
-        result = runner.invoke_with_connection(
-            ["dcm", "drop-version", project_name, "non_existent"]
+        _assert_project_has_deployments(
+            runner, project_name, expected_deployments={("DEPLOYMENT$3", "theDefault")}
         )
-        assert result.exit_code == 1, result.output
-        assert "Version does not exist" in result.output
 
-        # Try to drop non-existent version with --if-exists (should succeed)
+        # Try to drop the default deployment
         result = runner.invoke_with_connection(
-            ["dcm", "drop-version", project_name, "non_existent", "--if-exists"]
+            ["dcm", "drop-deployment", project_name, "DEPLOYMENT$3"]
         )
         assert result.exit_code == 0, result.output
         assert (
-            f"Version 'non_existent' dropped from DCM Project '{project_name}'"
+            f"Deployment 'DEPLOYMENT$3' dropped from DCM Project '{project_name}'"
+            in result.output
+        )
+
+        # Try to drop non-existent deployment without --if-exists (should fail)
+        result = runner.invoke_with_connection(
+            ["dcm", "drop-deployment", project_name, "non_existent"]
+        )
+        assert result.exit_code == 1, result.output
+        assert "Deployment does not exist" in result.output
+
+        # Try to drop non-existent deployment with --if-exists (should succeed)
+        result = runner.invoke_with_connection(
+            ["dcm", "drop-deployment", project_name, "non_existent", "--if-exists"]
+        )
+        assert result.exit_code == 0, result.output
+        assert (
+            f"Deployment 'non_existent' dropped from DCM Project '{project_name}'"
             in result.output
         )
 
@@ -404,15 +270,14 @@ def test_project_deploy_from_stage(
     project_directory,
 ):
     project_name = "project_descriptive_name"
-    entity_id = "my_project"
     other_stage_name = "other_project_stage"
 
     with project_directory("dcm_project") as project_root:
         # Create a new project
-        result = runner.invoke_with_connection(["dcm", "create", entity_id])
+        result = runner.invoke_with_connection(["dcm", "create", project_name])
         assert result.exit_code == 0, result.output
-        _assert_project_has_versions(
-            runner, project_name, expected_versions={("VERSION$1", None)}
+        _assert_project_has_deployments(
+            runner, project_name, expected_deployments=set()
         )
 
         # Edit file_a.sql to add a second table definition
@@ -429,7 +294,7 @@ def test_project_deploy_from_stage(
         assert result.exit_code == 0, result.output
 
         result = runner.invoke_with_connection(
-            ["stage", "copy", ".", f"@{other_stage_name}"]
+            ["stage", "copy", ".", f"@{other_stage_name}/project"]
         )
         assert result.exit_code == 0, result.output
 
@@ -440,7 +305,7 @@ def test_project_deploy_from_stage(
                 "plan",
                 project_name,
                 "--from",
-                f"@{other_stage_name}",
+                f"@{other_stage_name}/project",
                 "-D",
                 f"table_name='{test_database}.PUBLIC.MyTable'",
             ]
@@ -474,7 +339,7 @@ def test_project_deploy_from_stage(
                 "deploy",
                 project_name,
                 "--from",
-                f"@{other_stage_name}",
+                f"@{other_stage_name}/project",
                 "-D",
                 f"table_name='{test_database}.PUBLIC.MyTable'",
             ]
@@ -502,3 +367,191 @@ def test_project_deploy_from_stage(
         assert (
             "MYTABLE_SECOND" == table_check_result.json[0]["name"]
         ), "Table should exist after deploy"
+
+        # Clean up
+        result = runner.invoke_with_connection(["dcm", "drop", project_name])
+        assert result.exit_code == 0, result.output
+
+
+@pytest.mark.qa_only
+@pytest.mark.integration
+def test_project_plan_with_output_path(
+    runner,
+    test_database,
+    project_directory,
+):
+    """Test that DCM plan command with --output-path option writes output to the specified stage."""
+    project_name = "project_descriptive_name"
+    source_stage_name = "source_project_stage"
+    output_stage_name = "output_results_stage"
+    output_path = f"@{output_stage_name}/plan_results"
+
+    with project_directory("dcm_project") as project_root:
+        # Create a new project
+        result = runner.invoke_with_connection(["dcm", "create", project_name])
+        assert result.exit_code == 0, result.output
+        _assert_project_has_deployments(
+            runner, project_name, expected_deployments=set()
+        )
+
+        # Edit file_a.sql to add a table definition for testing
+        file_a_path = project_root / "file_a.sql"
+        original_content = file_a_path.read_text()
+        modified_content = (
+            original_content
+            + "\ndefine table identifier('{{ table_name }}_OUTPUT_TEST') (id int, name string);\n"
+        )
+        file_a_path.write_text(modified_content)
+
+        # Create source stage and upload files there
+        result = runner.invoke_with_connection(["stage", "create", source_stage_name])
+        assert result.exit_code == 0, result.output
+
+        result = runner.invoke_with_connection(
+            ["stage", "copy", ".", f"@{source_stage_name}/project"]
+        )
+        assert result.exit_code == 0, result.output
+
+        # Create output stage for plan results
+        result = runner.invoke_with_connection(["stage", "create", output_stage_name])
+        assert result.exit_code == 0, result.output
+
+        # Test plan with stage output-path option
+        result = runner.invoke_with_connection_json(
+            [
+                "dcm",
+                "plan",
+                project_name,
+                "--from",
+                f"@{source_stage_name}/project",
+                "--output-path",
+                output_path,
+                "-D",
+                f"table_name='{test_database}.PUBLIC.OutputTestTable'",
+            ]
+        )
+        assert result.exit_code == 0, result.output
+
+        # Verify that the output was written to the specified stage path
+        # Check if there are files in the output stage
+        stage_list_result = runner.invoke_with_connection_json(
+            ["stage", "list-files", output_path]
+        )
+        assert stage_list_result.exit_code == 0, stage_list_result.output
+
+        # There should be at least one file in the output location
+        assert (
+            len(stage_list_result.json) > 0
+        ), "Plan output should be written to the specified stage path"
+
+        # Verify that one of the files contains plan-related content by checking file names
+        file_names = [file["name"] for file in stage_list_result.json]
+        assert any(
+            "plan" in name.lower()
+            or "result" in name.lower()
+            or name.endswith((".json", ".txt", ".sql"))
+            for name in file_names
+        ), f"Expected plan output files, but found: {file_names}"
+
+        # Test plan with local output-path option
+        local_output_dir = "./dcm_output"
+        result = runner.invoke_with_connection_json(
+            [
+                "dcm",
+                "plan",
+                project_name,
+                "--from",
+                f"@{source_stage_name}/project",
+                "--output-path",
+                local_output_dir,
+                "-D",
+                f"table_name='{test_database}.PUBLIC.OutputTestTable'",
+            ]
+        )
+        assert result.exit_code == 0, result.output
+        assert os.path.exists(
+            local_output_dir
+        ), f"Local output directory {local_output_dir} does not exist"
+
+        local_files = set()
+        for root, dirs, files in os.walk(local_output_dir):
+            for file in files:
+                relative_path = os.path.relpath(
+                    os.path.join(root, file), local_output_dir
+                )
+                local_files.add(relative_path)
+
+        stage_files = set()
+        for name in file_names:
+            normalized_name = name.removeprefix(f"{output_stage_name}/plan_results/")
+            stage_files.add(normalized_name)
+
+        diff = stage_files.symmetric_difference(local_files)
+        assert (
+            not diff
+        ), f"Files present in stage but missing in local output directory: {stage_files - local_files}. Local files found but missing on stage: {local_files - stage_files}"
+
+        # Clean up stages
+        result = runner.invoke_with_connection(["stage", "drop", source_stage_name])
+        assert result.exit_code == 0, result.output
+
+        result = runner.invoke_with_connection(["stage", "drop", output_stage_name])
+        assert result.exit_code == 0, result.output
+
+        # Clean up project
+        result = runner.invoke_with_connection(["dcm", "drop", project_name])
+        assert result.exit_code == 0, result.output
+
+
+@pytest.mark.qa_only
+@pytest.mark.integration
+def test_dcm_plan_and_deploy_from_another_directory(
+    runner,
+    test_database,
+    project_directory,
+    tmp_path,
+):
+    project_name = "project_descriptive_name"
+
+    with project_directory("dcm_project") as project_root:
+        project_source_path = project_root
+
+    original_cwd = os.getcwd()
+    try:
+        os.chdir(tmp_path)
+
+        result = runner.invoke_with_connection(["dcm", "create", project_name])
+        assert result.exit_code == 0, result.output
+        assert f"DCM Project '{project_name}' successfully created." in result.output
+
+        result = runner.invoke_with_connection(
+            [
+                "dcm",
+                "plan",
+                project_name,
+                "-D",
+                f"table_name='{test_database}.PUBLIC.MyTable'",
+                "--from",
+                f"{project_source_path}",
+            ]
+        )
+        assert result.exit_code == 0, result.output
+
+        result = runner.invoke_with_connection(
+            [
+                "dcm",
+                "deploy",
+                project_name,
+                "-D",
+                f"table_name='{test_database}.PUBLIC.MyTable'",
+                "--from",
+                f"{project_source_path}",
+            ]
+        )
+        assert result.exit_code == 0, result.output
+    finally:
+        os.chdir(original_cwd)
+
+    # Clean up
+    result = runner.invoke_with_connection(["dcm", "drop", project_name])
+    assert result.exit_code == 0, result.output
